@@ -16,7 +16,7 @@ void add_to(std::vector<float>& target, Vec2<float> const& v)
     target.push_back(v.y);
 }
 
-std::vector<float> Context::generate_circle(Vec2f const& center, float radius,
+std::vector<float> Context::generate_circle(Vec2f center, float radius,
                                             bool include_center) const
 {
     if (radius < 1) { return {}; }
@@ -33,11 +33,11 @@ std::vector<float> Context::generate_circle(Vec2f const& center, float radius,
     return vertexData;
 }
 
-std::array<float, 4> Context::generate_line(double x0, double y0, double x1,
-                                            double y1)
+std::array<float, 4> Context::generate_line(Vec2f from, Vec2f to) const
 {
-    return {to_screen_x(x0 + 0.5), to_screen_y(y0 + 0.5), to_screen_x(x1 + 0.5),
-            to_screen_y(y1 + 0.5)};
+    auto a = to_screen(from + Vec2f{0.5, 0.5});
+    auto b = to_screen(to + Vec2f{0.5, 0.5});
+    return {a.x, a.y, b.x, b.y};
 }
 
 std::vector<float> Context::generate_lines(const float* screen_cords,
@@ -51,14 +51,11 @@ std::vector<float> Context::generate_lines(const float* screen_cords,
     return result;
 }
 
-std::array<float, 8> Context::generate_quad(float x, float y, float w,
-                                            float h) const
+std::array<float, 8> Context::generate_quad(Vec2f top_left, Vec2f size) const
 {
-    float x0 = to_screen_x(x);
-    float y0 = to_screen_y(y);
-    float x1 = to_screen_x(x + w);
-    float y1 = to_screen_y(y + h);
-    return std::array{x0, y0, x1, y0, x1, y1, x0, y1};
+    auto p0 = to_screen(top_left);
+    auto p1 = to_screen(top_left + size);
+    return std::array{p0.x, p0.y, p1.x, p0.y, p1.x, p1.y, p0.x, p1.y};
 }
 
 std::array<float, 16> Context::generate_quad_with_uvs(Vec2f pos,
@@ -102,31 +99,29 @@ std::array<float, 16> Context::rotated_quad_with_uvs(Vec2f center, Vec2f sz,
                       0.F,  1.F,  1.F,  1.F,  1.F,  0.F,  0.F,  0.F};
 }
 
-void Context::filled_rect(float x, float y, float w, float h)
+void Context::filled_rect(Vec2f top_left, Vec2f size)
 {
-    draw_filled(generate_quad(x, y, w, h), gl::Primitive::TriangleFan);
+    draw_filled(generate_quad(top_left, size), gl::Primitive::TriangleFan);
 }
 
-void Context::rect(float x, float y, float w, float h)
+void Context::rect(Vec2f top_left, Vec2f size)
 {
     glLineWidth(line_width);
-    draw_filled(generate_quad(x, y, w, h), gl::Primitive::LineLoop);
+    draw_filled(generate_quad(top_left, size), gl::Primitive::LineLoop);
 }
 
-void Context::line(float x0, float y0, float x1, float y1)
+void Context::line(Vec2f from, Vec2f to)
 {
     glLineWidth(line_width);
-    draw_filled(generate_line(x0, y0, x1, y1), gl::Primitive::Lines);
-    last_x = x1;
-    last_y = y1;
+    draw_filled(generate_line(from, to), gl::Primitive::Lines);
+    last_point = to;
 }
 
-void Context::line(float x1, float y1)
+void Context::line(Vec2f to)
 {
     glLineWidth(line_width);
-    draw_filled(generate_line(last_x, last_y, x1, y1), gl::Primitive::Lines);
-    last_x = x1;
-    last_y = y1;
+    draw_filled(generate_line(last_point, to), gl::Primitive::Lines);
+    last_point = to;
 }
 
 void Context::circle(Vec2f const& v, float r)
@@ -160,7 +155,6 @@ void Context::draw(gl::TexRef const& tex, Vec2f center, Vec2f size, float rot)
         size = {static_cast<float>(tex.width()),
                 static_cast<float>(tex.height())};
     }
-    // auto vdata = generate_quad_with_uvs(pos.x, pos.y, size.x, size.y);
     auto vdata = rotated_quad_with_uvs(center, size, rot);
     std::copy(tex.uvs().begin(), tex.uvs().end(), vdata.begin() + 8);
     draw_textured(vdata, gl::Primitive::TriangleFan);
@@ -173,7 +167,7 @@ Context::Context(Vec2f const& offs, Vec2f const& sz, GLuint fb)
               .get_program<ProgramCache::Colored, ProgramCache::NoTransform>()},
       textured{ProgramCache::get_instance()
                    .get_program<ProgramCache::Textured>()}, // NOLINT
-      filled{ProgramCache::get_instance().get_program<>()}  // NOLINT
+      filled{ProgramCache::get_instance().get_program<>()} // NOLINT
 {
     // auto in_color = textured.getUniformLocation("in_color");
     // auto in_pos = textured.getAttribute("in_pos");
@@ -191,24 +185,6 @@ Context::Context(float w, float h, GLuint fb)
     textured.setUniform("in_transform", mat);
 }
 
-/*
-: target{fb}, target_size{w, h}, fg{color::white},
-  colored{gl::ProgramCache::get_instance()
-              .get_program<gl::ProgramCache::Colored,
-                           ProgramCache::NoTransform>()},
-  textured{gl::ProgramCache::get_instance()
-               .get_program<gl::ProgramCache::Textured>()},
-  filled{gl::ProgramCache::get_instance().get_program<>()}
-{
-static const std::array<float, 16> mat{1, 0, 0, 0, 0, 1, 0, 0,
-                                       0, 0, 1, 0, 0, 0, 0, 1};
-gl::Color color = 0xffffffff;
-filled.setUniform("frag_color", color);
-filled.setUniform("in_transform", mat);
-textured.setUniform("frag_color", color);
-textured.setUniform("in_transform", mat);
-}
-*/
 template <typename CO>
 void Context::draw_filled(const CO& container, gl_wrap::Primitive primitive)
 {
@@ -263,10 +239,7 @@ void Context::clear(const gl_wrap::Color& col) const
 {
     glBindFramebuffer(GL_FRAMEBUFFER, target);
     gl::setViewport({target_size.x * vpscale, target_size.y * vpscale});
-    auto c = col.to_rgba();
-    c &= clear_mask;
-    gl_wrap::Color col2{c};
-    glClearColor(col2.red, col2.green, col2.blue, col2.alpha);
+    glClearColor(col.red, col.green, col.blue, col.alpha);
     glClear(GL_COLOR_BUFFER_BIT);
 }
 
@@ -274,8 +247,9 @@ std::vector<float> points;
 
 void Context::plot(Vec2f point, gl_wrap::Color col)
 {
-    points.push_back(to_screen_x(point.x));
-    points.push_back(to_screen_y(point.y));
+    auto p = to_screen(point);
+    points.push_back(p.x);
+    points.push_back(p.y);
     points.push_back(col.red);
     points.push_back(col.green);
     points.push_back(col.blue);
