@@ -16,47 +16,32 @@ class Context
 {
     GLuint target = 0;
     Vec2f offset{0, 0};
-    Vec2f target_size;
 
 public:
+    Vec2f target_size;
     float vpscale = 1.0F;
 
-    uint32_t clear_mask = 0xffffffff;
     float line_width = 1;
     gl_wrap::Color fg;
 
 private:
-    float last_x = 0;
-    float last_y = 0;
+    Vec2f last_point{0,0};
 
     gl_wrap::Program& colored;
     gl_wrap::Program& textured;
     gl_wrap::Program& filled;
 
-    template <typename T> constexpr float to_screen_x(T x) const
-    {
-        return (static_cast<float>(x) + offset.x) * 2.0F / target_size.x - 1.0F;
-    }
-
-    template <typename T> constexpr float to_screen_y(T y) const
-    {
-        return (static_cast<float>(y) + offset.y) * -2.0F / target_size.y +
-               1.0F;
-    }
-
     template <typename CO>
     void draw_filled(CO const& container, gl_wrap::Primitive primitive);
 
     template <typename CO>
     void draw_textured(CO const& container, gl_wrap::Primitive primitive);
 
-    std::vector<float> generate_circle(Vec2f const& center, float radius,
+    std::vector<float> generate_circle(Vec2f center, float radius,
                                        bool include_center = true) const;
-    std::array<float, 4> generate_line(double x0, double y0, double x1,
-                                       double y1);
+    std::array<float, 4> generate_line(Vec2f from, Vec2f to) const;
     std::vector<float> generate_lines(float const* screen_cords, int count) const;
-    std::array<float, 8> generate_quad(float x, float y, float w,
-                                       float h) const;
+    std::array<float, 8> generate_quad(Vec2f top_left, Vec2f size) const;
     std::array<float, 8> rotated_quad(Vec2f center, Vec2f sz, float rot) const;
     std::array<float, 16> generate_quad_with_uvs(Vec2f pos, Vec2f size) const;
 
@@ -88,10 +73,10 @@ public:
 
     void circle(Vec2f const& v, float r);
     void filled_circle(Vec2f const& v, float r);
-    void line(float x0, float y0, float x1, float y1);
-    void line(float x1, float y1);
-    void filled_rect(float x, float y, float w, float h);
-    void rect(float x, float y, float w, float h);
+    void line(Vec2f from, Vec2f to);
+    void line(Vec2f to);
+    void filled_rect(Vec2f top_left, Vec2f size);
+    void rect(Vec2f top_left, Vec2f size);
     void blit(gl_wrap::TexRef const& tex, Vec2f pos, Vec2f size);
     void draw(gl_wrap::TexRef const& tex, Vec2f center, Vec2f size, float rot);
 
