@@ -7,26 +7,28 @@
 #include "utf8.h"
 
 #include <GLFW/glfw3.h>
-#include <cmath>
 
 #include <array>
+#include <chrono>
 #include <deque>
 #include <filesystem>
-#include <memory>
+#include <thread>
 #include <unordered_map>
 #include <unordered_set>
-#include <vector>
 
 namespace fs = std::filesystem;
 
+using namespace std::chrono_literals;
+
 class GLFWWindow : public Screen
 {
 public:
     GLFWwindow* window = nullptr;
 
-    explicit GLFWWindow(GLFWwindow* win) : window(win)
-    {
+    explicit GLFWWindow(GLFWwindow* win) : window(win) { update_scale(); }
 
+    void update_scale()
+    {
         int fw = 0;
         int fh = 0;
         glfwGetFramebufferSize(window, &fw, &fh);
@@ -36,7 +38,6 @@ public:
         int h = 0;
         glfwGetWindowSize(window, &w, &h);
         log("win size %d %d\n", w, h);
-
         scale = static_cast<float>(fw) / w;
     }
 
@@ -46,9 +47,28 @@ public:
     }
 
     float scale = 1.0F;
-    float get_scale() override { return scale; }
+    float get_scale() override
+    {
+        update_scale();
+        return scale;
+    }
 
-    void swap() override { glfwSwapBuffers(window); }
+    using clk = std::chrono::steady_clock;
+    clk::time_point last{};
+    clk::duration frame_time = std::chrono::microseconds(1000000 / 60);
+
+    void swap() override
+    {
+        glfwSwapBuffers(window);
+        clk::time_point t = clk::now();
+        auto d = t - last;
+        //printf("Frame time %.3f\n", d.count() / 1000000.0);
+        if (d + 1ms < frame_time) {
+            //printf("Sleeping %lld\n", (frame_time - d).count());
+            std::this_thread::sleep_for(frame_time - d - 1ms);
+        }
+        last = t;
+    }
 
     void set_target() override
     {
@@ -85,22 +105,9 @@ class GLFWSystem : public System
     };
 
     static inline std::unordered_map<Key, uint32_t> reverse_map;
-    std::unordered_set<uint32_t> pressed;
-
-    static constexpr bool in_unicode_range(uint32_t c)
-    {
-        return c >= 0x20 && c <= 0x0f'ffff;
-    }
-
-    static uint32_t glfw2key(uint32_t code)
-    {
-        auto it = glfw_map.find(code);
-        if (it != glfw_map.end()) { return static_cast<int>(it->second); }
-        return code;
-    }
-
     static inline GLFWSystem* system = nullptr;
 
+    std::unordered_set<uint32_t> pressed;
     GLFWwindow* window = nullptr;
 
 public:
@@ -154,6 +161,7 @@ public:
         // printf("GL %d.%d\n", GLAD_VERSION_MAJOR(version),
         // GLAD_VERSION_MINOR(version));
 #endif
+        glfwSwapInterval(1);
         // printf("%s\n", glGetString(GL_VERSION));
         glEnable(GL_BLEND);
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -174,6 +182,9 @@ public:
         glfwSetCursorPosCallback(window, [](GLFWwindow*, double x, double y) {
             system->mouse_move(x, y);
         });
+        glfwSetWindowSizeCallback(window, [](GLFWwindow*, int w, int h) {
+            system->resized(w, h);
+        });
         glViewport(0, 0, settings.display_width, settings.display_height);
         return std::make_shared<GLFWWindow>(window);
     }
@@ -206,14 +217,16 @@ public:
         return {x, y};
     }
 
-    void char_was_pressed(int codepoint)
+    void char_was_pressed(unsigned codepoint)
     {
         auto s = utf8::utf8_encode(
             std::u32string(1, static_cast<char32_t>(codepoint)));
         event_queue.emplace_back(TextEvent{s, 0});
     }
 
-    void key_was_pressed(int key, int scancode, int action, int mods)
+    void resized(int w, int h) { event_queue.emplace_back(ResizeEvent{w, h}); }
+
+    void key_was_pressed(int key, int /* scancode */, int action, int mods)
     {
         auto down = (action != GLFW_RELEASE);
         if (key >= 0x20 && key <= 0x7f) {
@@ -249,7 +262,8 @@ public:
             return glfwGetMouseButton(window, 2) != GLFW_RELEASE;
         }
         if (code >= 0x20 && code <= 0x7f) {
-            return glfwGetKey(window, std::toupper(code)) != GLFW_RELEASE;
+            return glfwGetKey(window, std::toupper(static_cast<int>(code))) !=
+                   GLFW_RELEASE;
         }
 
         auto it = reverse_map.find(key);
@@ -259,7 +273,6 @@ public:
         return false;
     }
 
-    bool quit = false;
     bool loop_called = false;
 
     bool was_pressed(uint32_t code, int device = -1) override
