@@ -39,42 +39,18 @@ inline void add_console_class(py::module_ const& mod)
 {
     // Console
     py::class_<FullConsole, std::shared_ptr<FullConsole>>(mod, "Console")
-        .def(py::init<>(&make_console), py::arg("cols") = 80,
-             py::arg("rows") = 50, py::arg("font_file") = "",
-             py::arg("tile_size") = Vec2f{0, 0}, py::arg("font_size") = 16)
-        .def("render", &FullConsole::render, py::arg("context"),
-             py::arg("pos") = Vec2f(0, 0), py::arg("size") = Vec2f(-1, -1),
-             "Render the console to the display")
-        .def(
-            "put",
-            [](std::shared_ptr<FullConsole> const& thiz, float x, float y,
-               uint32_t c) { thiz->put(x, y, c); },
-            "Put char at position")
-        .def(
-            "put",
-            [](std::shared_ptr<FullConsole> const& thiz, float x, float y,
-               std::string const& t) { thiz->text(x, y, t); },
-            "Put char at position")
-        .def(
-            "put",
-            [](std::shared_ptr<FullConsole> const& thiz, Vec2f pos,
-               std::string const& t) { thiz->text(pos.x, pos.y, t); },
-            "Put char at position")
+        .def(py::init<>(&make_console), "cols"_a = 80, "rows"_a = 50,
+             "font_file"_a = "", "tile_size"_a = Vec2i{0, 0},
+             "font_size"_a = 16)
+        .def("render", &FullConsole::render, "context"_a, "pos"_a = Vec2f(0, 0),
+             "size"_a = Vec2f(-1, -1), "Render the console to the display")
+        .def("put", &FullConsole::put, "pos"_a, "tile"_a, "Put char at position")
         .def("get", &FullConsole::get, "Get char at position")
-        .def(
-            "get",
-            [](FullConsole const& con, Vec2f const& pos) {
-                return con.get(pos.x, pos.y);
-            },
-            "Get char at position")
         .def_readwrite("cursor_on", &FullConsole::cursor_on)
-        .def_property("cursor_pos", [](FullConsole& thiz) {
-            return Vec2f(thiz.get_cursor());
-            }, [](FullConsole& thiz, Vec2f const& v) {
-                thiz.set_cursor(v.x, v.y);
-            })
+        .def_property("cursor_pos", &FullConsole::get_cursor,
+                      &FullConsole::set_cursor)
         .def("get_tiles", &FullConsole::get_tiles)
-        .def("set_tiles", &FullConsole::set_tiles)
+        .def("set_tiles", &FullConsole::set_tiles, "tiles"_a)
         .def("clear", &FullConsole::clear)
         .def("set_color", &FullConsole::set_color)
         .def_property_readonly("grid_size", &FullConsole::get_size,
@@ -86,12 +62,15 @@ inline void add_console_class(py::module_ const& mod)
         .def("cancel_line", &FullConsole::stop_line, "Stop line edit mode")
         .def("set_line", &FullConsole::set_line, "Change the edited line")
         .def("get_font_image", &FullConsole::get_font_texture)
-        .def("get_image_for", &FullConsole::get_texture_for_char, "")
-        .def("write", [](FullConsole& con, std::vector<char32_t> const& data) {
-            con.write(utf8::utf8_encode(data));
-            })
-        .def("write", static_cast<void (FullConsole::*)(std::string const&)>(
-                          &FullConsole::write))
+        .def("get_image_for", &FullConsole::get_texture_for_char, "tile"_a, "")
+        .def(
+            "write",
+            [](FullConsole& con, std::vector<char32_t> const& data) {
+                con.write(utf8::utf8_encode(data));
+            },
+            "tiles"_a)
         .def("write",
-             static_cast<void (FullConsole::*)(char32_t)>(&FullConsole::write));
+             static_cast<void (FullConsole::*)(std::string const&)>(
+                 &FullConsole::write),
+             "text"_a);
 }
