@@ -17,13 +17,13 @@ inline auto add_screen_class(py::module_ const& mod)
     auto screen = py::class_<Screen, std::shared_ptr<Screen>>(mod, "Screen");
     screen.def("set_as_target", &Screen::set_target);
     screen.def_property_readonly("frame_counter", [](Screen const&) {
-      return Machine::get_instance().frame_counter;
+        return Machine::get_instance().frame_counter;
     });
     screen.def_property_readonly("context", [](Screen const&) {
         return Machine::get_instance().context;
     });
     screen.def_property_readonly(
-        "size", [](Screen const& screen) { return Vec2f{screen.get_size()}; });
+        "size", [](Screen const& screen) { return Vec2i{screen.get_size()}; });
     screen.def_property_readonly(
         "width", [](Screen const& s) { return s.get_size().first; });
     screen.def_property_readonly(
@@ -36,6 +36,8 @@ inline auto add_screen_class(py::module_ const& mod)
             m.context->flush();
             screen->swap();
         },
-        "Swap display");
+        "Synchronize with the frame rate of the display and swap buffers. This "
+        "is normally the last thing you do in your render loop.");
+
     return screen;
 }
