@@ -12,6 +12,10 @@ namespace py = pybind11;
 
 inline void add_key_module(py::module_ const& mod)
 {
+    mod.attr("MOD_SHIFT") = 1;
+    mod.attr("MOD_CTRL") = 2;
+    mod.attr("MOD_ALT") = 4;
+
 #define KEY(x) mod.attr(#x) = static_cast<int>(Key::x)
     KEY(LEFT);
     KEY(RIGHT);
