@@ -68,6 +68,12 @@ struct ClickEvent
     int buttons;
 };
 
+struct ResizeEvent
+{
+    int w;
+    int h;
+};
+
 struct MoveEvent
 {
     float x;
@@ -82,7 +88,7 @@ struct TextEvent
 };
 
 using AnyEvent = std::variant<NoEvent, KeyEvent, MoveEvent, ClickEvent,
-                              TextEvent, QuitEvent>;
+                              TextEvent, ResizeEvent, QuitEvent>;
 
 class Screen
 {
